BinaryIVFIndexImpl

Struct BinaryIVFIndexImpl 

pub struct BinaryIVFIndexImpl { /* private fields */ }
Native implementation of a binary IVF index.

Implementations

Source

impl BinaryIVFIndexImpl

pub fn nprobe(&self) -> u32

Get number of probes at query time

pub fn set_nprobe(&mut self, value: u32)

Set number of probes at query time

pub fn nlist(&self) -> u32

Get number of possible key values

pub fn max_codes(&self) -> u32

Get max number of codes to visit to do a query

pub fn set_max_codes(&self, value: u32)

Set max number of codes to visit to do a query

pub fn imbalance_factor(&self) -> f64

Check the inverted lists’ imbalance factor.

1 = perfectly balanced, > 1: imbalanced